package io.github.pearstack.lock.service;

import org.aspectj.lang.JoinPoint;

/**
 * 分布式锁的业务接口层
 *
 * @author lihao3
 * @date 2021/12/23 13:35
 */
public interface LockService<T> {

  /**
   * 获取锁的实现对象
   *
   * @param joinPoint aop切面方法
   * @param name 对应注解的name属性
   * @param keys 对应注解的keys属性
   * @return 分布式锁名称
   */
  T getLockObject(JoinPoint joinPoint, String name, String[] keys);

  /**
   * 上锁
   *
   * @param lockObject 锁的实现对象
   * @param expire 锁的过期时间
   * @param acquireTimeout 获取锁的超时时间
   * @return 上锁是否成功
   * @throws InterruptedException 上锁异常
   */
  Boolean onLock(T lockObject, Long expire, Long acquireTimeout) throws InterruptedException;

  /**
   * 解锁
   *
   * @param lockObject 锁的实现对象
   */
  void unLock(T lockObject);
}
